
from setuptools import setup, find_packages

setup(
    name="PyPILC",
    version="1.2.0",
    packages=find_packages(),
    install_requires=[],
    description="pipcreator",
    long_description="README yok",
    long_description_content_type="text/markdown",
    author="Senin İsmin",
    author_email="sen@example.com",
    url="https://github.com/username/PyPILC",
)
